<?php
/**
 * @file
 */

/**
 * Implements hook_drush_command().
 */
function provision_reinstall_drush_command() {
  $items = array();

  $items['provision-reinstall'] = array(
    'description' => 'Reinstall a site.',
    'examples' => array(
      'drush @site provision-reinstall' => 'Invokes Provision Delete and Install tasks to simulate a site reinstall.',
    ),
    'options' => array(
      'client_email' => dt('The email address of the client to use.'),
      'cancel' => dt('Cancel the task by extra argument'),
    ),
    'bootstrap' => DRUSH_BOOTSTRAP_DRUSH,
  );

  return $items;
}

/**
 * Drush Provision Reinstall task callback.
 *
 * Invokes Provision Delete and Install tasks to simulate a site reinstall.
 */
function drush_provision_reinstall() {
  $cancel = drush_get_option('cancel');
  if ($cancel) {
    drush_log('Task is canceled', 'notice');
    return ;
  }
  $arguments = drush_get_context('stdin');
  /*$arguments = array_diff_key($arguments, array_flip(array('x')));
  //-----------DEBUGGING----------
  drush_log(__FUNCTION__ . 'DEBUG:<pre>'. print_r($arguments, TRUE) .'</pre>', 'error');
  //-----------END DEBUGGING----------
return ;*/

  $d = clone d();
  $d_name = $d->name;
  $save_data = array(
    'context_type' => 'site',
    'platform' => $d->platform->name,
    'db_server' => $d->db_server->name,
    'uri' => $d->uri,
    'client_name' => $d->client_name,
    'client_email' => $d->client_email,
    'profile' => $d->profile,
  );
  provision_backend_invoke($d_name, "provision-delete");
  drush_invoke_process('@none', "provision-save", array($d_name), $save_data);
  provision_backend_invoke($d_name, "provision-install", array(), $arguments);
}
